@@ -105,8 +105,7 @@ __all__ = [
     'LINK', 'INET', 'TRANS', 'APP', 'RAW',                  # Layer Macros
     'DPKT', 'Scapy', 'PyShark', 'PCAPKit',                  # Engine Macros
 
-    # Protocol Numbers
-    'LINKTYPE', 'ETHERTYPE', 'TRANSTYPE',
+    'LINKTYPE', 'ETHERTYPE', 'TRANSTYPE', 'APPTYPE',        # Protocol Numbers
 
     'NoPayload',                                            # No Payload
     'Raw',                                                  # Raw Packet
@@ -124,4 +123,4 @@ __all__ = [
 ]
 
 #: version number
-__version__ = '1.0.2.post7'
+__version__ = '1.3.1.post18'
