@@ -64,6 +64,7 @@ __all__ = [
     'IPv4AddressField', 'IPv6AddressField',                 # IP address protocol fields
     'IPv4InterfaceField', 'IPv6InterfaceField',
     'ListField', 'OptionField',                             # container protocol fields
+    'SeekableReader',                                       # Seekable Reader
 
     # pcapkit.dumpkit
     'PCAPIO',                                               # PCAP Dumper
@@ -71,7 +72,7 @@ __all__ = [
 
     # pcapkit.foundation
     'Extractor',                                            # Extraction
-    'TraceFlow',                                            # Trace Flow
+    'TCP_TraceFlow',                                        # Trace Flow
 
     # pcapkit.foundation.reassembly
     'IPv4_Reassembly', 'IPv6_Reassembly',                   # IP Reassembly
@@ -79,18 +80,22 @@ __all__ = [
 
     # pcapkit.foundation.registry
     'register_protocol',
-    'register_linktype', 'register_pcap', 'register_pcapng',
-    'register_ethertype', 'register_transtype',
-    'register_port', 'register_tcp_port', 'register_udp_port',
-    'register_output',
-    'register_extractor_dumper', 'register_extractor_engine',
-    'register_traceflow',
+    'register_linktype',
+    'register_pcap', 'register_pcapng',
+    'register_ethertype',
+    'register_transtype',
+    'register_ipv4_option', 'register_hip_parameter', 'register_hopopt_option',
+    'register_ipv6_opts_option', 'register_ipv6_route_routing',
+    'register_mh_message', 'register_mh_option', 'register_mh_extension',
+    'register_apptype',
+    'register_tcp', 'register_udp',
+    'register_tcp_option', 'register_tcp_mp_option',
+    'register_http_frame',
     'register_pcapng_block', 'register_pcapng_option', 'register_pcapng_secrets',
     'register_pcapng_record',
-    'register_hopopt', 'register_ipv6_opts', 'register_ipv6_route',
-    'register_ipv4', 'register_hip',
-    'register_tcp', 'register_mptcp',
-    'register_http',
+    'register_extractor_engine',
+    'register_dumper',
+    'register_extractor_dumper', 'register_traceflow_dumper',
 
     # pcapkit.interface
     'extract', 'reassemble', 'trace',                       # Interface Functions
@@ -99,7 +104,7 @@ __all__ = [
     'DPKT', 'Scapy', 'PyShark', 'PCAPKit',                  # Engine Macros
 
     # pcapkit.protocols
-    'LINKTYPE', 'ETHERTYPE', 'TRANSTYPE',                   # Protocol Numbers
+    'LINKTYPE', 'ETHERTYPE', 'TRANSTYPE', 'APPTYPE',        # Protocol Numbers
     'Header', 'Frame',                                      # PCAP Headers
     'NoPayload',                                            # No Payload
     'Raw',                                                  # Raw Packet
