@@ -16,6 +16,8 @@ if TYPE_CHECKING:
 
     from typing_extensions import Literal, Self
 
+    from pcapkit.protocols.schema.schema import Schema
+
 _T = TypeVar('_T')
 
 
@@ -28,19 +30,33 @@ class NoValueType:
         return False
 
 
-#: NoValueType: Default value for :attr:`_Field.default`.
+#: NoValueType: Default value for :attr:`FieldBase.default`.
 NoValue = NoValueType()
 
 
-class _Field(Generic[_T], metaclass=abc.ABCMeta):
+class FieldMeta(abc.ABCMeta, Generic[_T]):
+    """Meta class to add dynamic support to :class:`FieldBase`.
+
+    This meta class is used to generate necessary attributes for the
+    :class:`FieldBase` class. It can be useful to reduce unnecessary
+    registry calls and simplify the customisation process.
+
+    """
+
+
+class FieldBase(Generic[_T], metaclass=FieldMeta):
     """Internal base class for protocol fields.
 
     Important:
-        A negative value of :attr:`~_Field.length` indicates that the field
+        A negative value of :attr:`~FieldBase.length` indicates that the field
         is variable-length (i.e., length unspecified) and thus
-        :meth:`~_Field.pack` should be considerate of the template format
+        :meth:`~FieldBase.pack` should be considerate of the template format
         and the actual value provided for packing.
 
+    Args:
+        *args: Arbitrary positional arguments.
+        **kwargs: Arbitrary keyword arguments.
+
     """
 
     if TYPE_CHECKING:
@@ -98,9 +114,8 @@ class _Field(Generic[_T], metaclass=abc.ABCMeta):
         Returns:
             Updated field instance.
 
-        Notes:
-            This method will return a new instance of :class:`_Field` instead of
-            updating the current instance.
+        This method will return a new instance of :class:`FieldBase` instead of
+        updating the current instance.
 
         """
         new_self = copy.copy(self)
@@ -109,7 +124,9 @@ class _Field(Generic[_T], metaclass=abc.ABCMeta):
 
     # NOTE: This method is created as a placeholder for the necessary attributes.
     def __init__(self, *args: 'Any', **kwargs: 'Any') -> 'None':
-        self._name = f'<{type(self).__name__[:-5].lower()}>'
+        if not hasattr(self, '_name'):
+            self._name = f'<{type(self).__name__[:-5].lower()}>'
+
         self._default = NoValue
         self._template = '0s'
         self._callback = lambda *_: None
@@ -119,6 +136,22 @@ class _Field(Generic[_T], metaclass=abc.ABCMeta):
             return f'<{self.__class__.__name__}>'
         return f'<{self.__class__.__name__} {self.name}>'
 
+    def __set_name__(self, owner: 'Schema', name: 'str') -> 'None':
+        """Set field name and update field list (if applicable).
+
+        This method is to be called by the metaclass during class creation.
+        It is used to set the field name and update the field list, i.e.,
+        :attr:`Schema.__fields__ <pcapkit.protocols.schema.schema.Schema.__fields__>`
+        mapping dictionary.
+
+        """
+        # Update field list (if applicable)
+        if hasattr(owner, '__fields__'):
+            owner.__fields__[name] = self
+
+        # Set field name
+        self.name = name
+
     def pre_process(self, value: '_T', packet: 'dict[str, Any]') -> 'Any':  # pylint: disable=unused-argument
         """Process field value before construction (packing).
 
@@ -181,7 +214,7 @@ class _Field(Generic[_T], metaclass=abc.ABCMeta):
         return self.post_process(value, packet)
 
 
-class Field(_Field[_T], Generic[_T]):
+class Field(FieldBase[_T], Generic[_T]):
     """Base class for protocol fields.
 
     Args:
@@ -189,7 +222,7 @@ class Field(_Field[_T], Generic[_T]):
             an integer value and accept the current packet as its only argument.
         default: Field default value, if any.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -204,7 +237,10 @@ class Field(_Field[_T], Generic[_T]):
     def __init__(self, length: 'int | Callable[[dict[str, Any]], int]',
                  default: '_T | NoValueType' = NoValue,
                  callback: 'Callable[[Self, dict[str, Any]], None]' = lambda *_: None) -> 'None':
-        self._name = '<unknown>'
+        #self._name = '<unknown>'
+        if not hasattr(self, '_name'):
+            self._name = f'<{type(self).__name__[:-5].lower()}>'
+
         self._default = default
         self._callback = callback
 
@@ -222,9 +258,8 @@ class Field(_Field[_T], Generic[_T]):
         Returns:
             New instance of :class:`Field`.
 
-        Notes:
-            This method will return a new instance of :class:`Field` instead of
-            updating the current instance.
+        This method will return a new instance of :class:`Field` instead of
+        updating the current instance.
 
         """
         new_self = copy.copy(self)
