@@ -3,10 +3,9 @@
 
 import abc
 import ipaddress
-from sys import prefix
 from typing import TYPE_CHECKING, Generic, TypeVar, cast
 
-from pcapkit.corekit.fields.field import _T, Field, NoValue
+from pcapkit.corekit.fields.field import Field, NoValue
 from pcapkit.utilities.exceptions import FieldValueError
 
 __all__ = [
@@ -23,6 +22,8 @@ if TYPE_CHECKING:
     from pcapkit.corekit.fields.field import NoValueType
 
 
+_T = TypeVar('_T', 'IPv4Address', 'IPv6Address',
+             'IPv4Interface', 'IPv6Interface')
 _AT = TypeVar('_AT', 'IPv4Address', 'IPv6Address')
 _IT = TypeVar('_IT', 'IPv4Interface', 'IPv6Interface')
 
@@ -33,7 +34,7 @@ class _IPField(Field[_T], Generic[_T]):
     Args:
         length: Field size (in bytes).
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -49,7 +50,7 @@ class _IPAddressField(_IPField[_AT]):
     Args:
         length: Field size (in bytes).
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -96,7 +97,7 @@ class IPv4AddressField(_IPAddressField[ipaddress.IPv4Address]):
     Args:
         default: Field default value, if any.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -118,7 +119,7 @@ class IPv6AddressField(_IPAddressField[ipaddress.IPv6Address]):
     Args:
         default: Field default value, if any.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -142,7 +143,7 @@ class _IPInterfaceField(_IPField[_IT]):
             an integer value and accept the current packet as its only argument.
         default: Field default value, if any.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -153,7 +154,7 @@ class IPv4InterfaceField(_IPInterfaceField[ipaddress.IPv4Interface]):
     Args:
         default: Field default value, if any.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -216,7 +217,7 @@ class IPv6InterfaceField(_IPInterfaceField[ipaddress.IPv6Interface]):
     Args:
         default: Field default value, if any.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
