@@ -2,6 +2,8 @@
 """PCAP Dumper
 =================
 
+.. module:: pcapkit.dumper.pcap
+
 :mod:`pcapkit.dumpkit.pcap` is the dumper for :mod:`pcapkit` implementation,
 specifically for PCAP format, which is alike those described in
 :mod:`dictdumper`.
@@ -10,27 +12,35 @@ specifically for PCAP format, which is alike those described in
 import sys
 from typing import TYPE_CHECKING
 
-import dictdumper
-
+from pcapkit.dumpkit.common import DumperBase as Dumper
 from pcapkit.protocols.misc.pcap.frame import Frame
 from pcapkit.protocols.misc.pcap.header import Header
 
 if TYPE_CHECKING:
     from enum import IntEnum as StdlibIntEnum
-    from typing import Any, BinaryIO, Optional
+    from typing import IO, Any, Optional
 
     from aenum import IntEnum as AenumIntEnum
     from typing_extensions import Literal
 
-    from pcapkit.const.reg.linktype import LinkType as RegType_LinkType
+    from pcapkit.const.reg.linktype import LinkType as Enum_LinkType
 
 __all__ = [
     'PCAPIO',
 ]
 
 
-class PCAPIO(dictdumper.Dumper):
-    """PCAP file dumper."""
+class PCAPIO(Dumper):
+    """PCAP file dumper.
+
+    Args:
+        fname: output file name
+        protocol: data link type
+        byteorder: header byte order
+        nanosecond: nanosecond-resolution file flag
+        **kwargs: arbitrary keyword arguments
+
+    """
 
     ##########################################################################
     # Properties.
@@ -45,7 +55,7 @@ class PCAPIO(dictdumper.Dumper):
     # Data models.
     ##########################################################################
 
-    def __init__(self, fname: 'str', *, protocol: 'RegType_LinkType | StdlibIntEnum | AenumIntEnum | str | int',
+    def __init__(self, fname: 'str', *, protocol: 'Enum_LinkType | StdlibIntEnum | AenumIntEnum | str | int',
                  byteorder: 'Literal["big", "little"]' = sys.byteorder,
                  nanosecond: 'bool' = False, **kwargs: 'Any') -> 'None':  # pylint: disable=arguments-differ
         """Initialise dumper.
@@ -62,7 +72,7 @@ class PCAPIO(dictdumper.Dumper):
         self._fnum = 1
         #: bool: Nanosecond-resolution file flag.
         self._nsec = nanosecond
-        #: RegType_LinkType | StdlibIntEnum | AenumIntEnum | str | int: Data link type.
+        #: Enum_LinkType | StdlibIntEnum | AenumIntEnum | str | int: Data link type.
         self._link = protocol
 
         super().__init__(fname, protocol=protocol, byteorder=byteorder, nanosecond=nanosecond, **kwargs)
@@ -86,7 +96,7 @@ class PCAPIO(dictdumper.Dumper):
     # Utilities.
     ##########################################################################
 
-    def _dump_header(self, *, protocol: 'RegType_LinkType | StdlibIntEnum | AenumIntEnum | str | int',  # pylint: disable=arguments-differ
+    def _dump_header(self, *, protocol: 'Enum_LinkType | StdlibIntEnum | AenumIntEnum | str | int',  # pylint: disable=arguments-differ
                      byteorder: 'Literal["big", "little"]' = sys.byteorder, nanosecond: 'bool' = False,
                      **kwargs: 'Any') -> 'None':  # pylint: disable=unused-argument
         """Initially dump file heads and tails.
@@ -106,7 +116,7 @@ class PCAPIO(dictdumper.Dumper):
         with open(self._file, 'wb') as file:
             file.write(packet)
 
-    def _append_value(self, value: 'Frame', file: 'BinaryIO', name: 'str') -> 'None':  # pylint: disable=unused-argument
+    def _append_value(self, value: 'Frame', file: 'IO[bytes]', name: 'str') -> 'None':  # pylint: disable=unused-argument
         """Call this function to write contents.
 
         Args:
