@@ -13,7 +13,7 @@ support, as is used by :class:`pcapkit.foundation.extraction.Extractor`.
 from typing import TYPE_CHECKING, cast
 
 from pcapkit.const.reg.linktype import LinkType as Enum_LinkType
-from pcapkit.foundation.engines.engine import Engine
+from pcapkit.foundation.engines.engine import EngineBase as Engine
 from pcapkit.utilities.exceptions import FormatError, stacklevel
 from pcapkit.utilities.warnings import AttributeWarning, DPKTWarning, warn
 
@@ -38,20 +38,23 @@ class DPKT(Engine['DPKTPacket']):
         extractor: :class:`~pcapkit.foundation.extraction.Extractor` instance.
 
     """
+    if TYPE_CHECKING:
+        import dpkt
+
+        #: Engine extraction package.
+        _expkg: 'dpkt'
+        #: Engine extraction temporary storage.
+        _extmp: 'Reader'
 
     ##########################################################################
-    # Properties.
+    # Defaults.
     ##########################################################################
 
-    @classmethod
-    def name(cls) -> 'str':
-        """Engine name."""
-        return 'DPKT'
+    #: Engine name.
+    __engine_name__ = 'DPKT'
 
-    @classmethod
-    def module(cls) -> 'str':
-        """Engine module name."""
-        return 'dpkt'
+    #: Engine module name.
+    __engine_module__ = 'dpkt'
 
     ##########################################################################
     # Data models.
@@ -72,17 +75,18 @@ class DPKT(Engine['DPKTPacket']):
     def run(self) -> 'None':
         """Call :class:`dpkt.pcap.Reader` to extract PCAP files.
 
-        This method assigns :attr:`self._expkg <Extractor._expkg>` as :mod:`dpkt` and
-        :attr:`self._extmp <Extractor._extmp>` as an iterator from :class:`dpkt.pcap.Reader`.
+        This method assigns :attr:`self._expkg <DPKT._expkg>`
+        as :mod:`dpkt` and :attr:`self._extmp <DPKT._extmp>`
+        as an iterator from :class:`dpkt.pcap.Reader`.
 
         Warns:
-            AttributeWarning: If :attr:`self._exlyr <Extractor._exlyr>` and/or
-                :attr:`self._exptl <Extractor._exptl>` is provided as the DPKT
-                engine currently does not support such operations.
+            AttributeWarning: If :attr:`self.extractor._exlyr <pcapkit.foundation.extraction.Extractor._exlyr>`
+                and/or :attr:`self.extractor._exptl <pcapkit.foundation.extraction.Extractor._exptl>`
+                is provided as the DPKT engine currently does not support such operations.
 
         Raises:
             FormatError: If the file format is not supported, i.e., not a PCAP
-                file.
+                and/or PCAP-NG file.
 
         """
         from pcapkit.foundation.engines.pcap import PCAP
@@ -117,10 +121,11 @@ class DPKT(Engine['DPKTPacket']):
         """Read frames with DPKT engine.
 
         Returns:
-            dpkt.dpkt.Packet: Parsed frame instance.
+            Parsed frame instance.
 
         See Also:
-            Please refer to :meth:`_default_read_frame` for more operational information.
+            Please refer to :meth:`PCAP.read_frame <pcapkit.foundation.engines.pcap.PCAP.read_frame>`
+            for more operational information.
 
         """
         from pcapkit.toolkit.dpkt import (ipv4_reassembly, ipv6_reassembly, packet2dict,
