@@ -3,8 +3,9 @@
 
 from typing import TYPE_CHECKING
 
-from pcapkit.corekit.infoclass import Info
-from pcapkit.protocols.data.application.http import HTTP as DataType_HTTP
+from pcapkit.corekit.infoclass import info_final
+from pcapkit.protocols.data.data import Data
+from pcapkit.protocols.data.protocol import Protocol
 
 if TYPE_CHECKING:
     from typing import Optional
@@ -15,6 +16,7 @@ if TYPE_CHECKING:
     from pcapkit.const.http.frame import Frame
     from pcapkit.const.http.setting import Setting
     from pcapkit.corekit.multidict import OrderedMultiDict
+    from pcapkit.protocols.schema.application.httpv2 import FrameType
 
 __all__ = [
     'HTTP',
@@ -24,16 +26,20 @@ __all__ = [
     'PushPromiseFrameFlags', 'PingFrameFlags', 'ContinuationFrameFlags',
 
     'UnassignedFrame', 'DataFrame', 'HeadersFrame', 'PriorityFrame',
-    'RstStreamFrame', 'SettingsFrame', 'PushPromiseFrame', 'PingFrame',
+    'RSTStreamFrame', 'SettingsFrame', 'PushPromiseFrame', 'PingFrame',
     'GoawayFrame', 'WindowUpdateFrame', 'ContinuationFrame',
 ]
 
 
-class Flags(Info):
+class Flags(Data):
     """Data model for HTTP/2 flags."""
 
+    if TYPE_CHECKING:
+        #: Flags as in combination value.
+        __value__: 'FrameType.Flags'
 
-class HTTP(DataType_HTTP):
+
+class HTTP(Protocol):
     """Data model for HTTP/2 protocol."""
 
     #: Length.
@@ -46,18 +52,20 @@ class HTTP(DataType_HTTP):
     sid: 'int'
 
 
+@info_final
 class UnassignedFrame(HTTP):
     """Data model for HTTP/2 unassigned frame."""
 
     #: Flags.
     flags: 'Literal[None]'
     #: Frame payload.
-    data: 'Optional[bytes]'
+    data: 'bytes'
 
     if TYPE_CHECKING:
-        def __init__(self, length: 'int', type: 'Frame', flags: 'Literal[None]', sid: 'int', data: 'Optional[bytes]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, length: 'int', type: 'Frame', flags: 'Literal[None]', sid: 'int', data: 'bytes') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class DataFrameFlags(Flags):
     """Data model for HTTP/2 ``DATA`` frame flags."""
 
@@ -70,6 +78,7 @@ class DataFrameFlags(Flags):
         def __init__(self, END_STREAM: 'bool', PADDED: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class DataFrame(HTTP):
     """Data model for HTTP/2 ``DATA`` frame."""
 
@@ -78,12 +87,13 @@ class DataFrame(HTTP):
     #: Padded length.
     pad_len: 'int'
     #: Frame payload.
-    data: 'Optional[bytes]'
+    data: 'bytes'
 
     if TYPE_CHECKING:
-        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', pad_len: 'int', sid: 'int', data: 'Optional[bytes]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, length: 'int', type: 'Frame', flags: 'DataFrameFlags', pad_len: 'int', sid: 'int', data: 'bytes') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class HeadersFrameFlags(Flags):
     """Data model for HTTP/2 ``HEADERS`` frame flags."""
 
@@ -100,6 +110,7 @@ class HeadersFrameFlags(Flags):
         def __init__(self, END_STREAM: 'bool', END_HEADERS: 'bool', PADDED: 'bool', PRIORITY: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class HeadersFrame(HTTP):
     """Data model for HTTP/2 ``HEADERS`` frame."""
 
@@ -108,18 +119,19 @@ class HeadersFrame(HTTP):
     #: Padded length.
     pad_len: 'int'
     #: Exclusive dependency.
-    excl_dependency: 'Optional[bool]'
+    excl_dependency: 'bool'
     #: Stream dependency.
-    stream_dependency: 'Optional[int]'
+    stream_dependency: 'int'
     #: Weight.
-    weight: 'Optional[int]'
+    weight: 'int'
     #: Header block fragment.
-    fragment: 'Optional[bytes]'
+    fragment: 'bytes'
 
     if TYPE_CHECKING:
-        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', pad_len: 'int', sid: 'int', excl_dependency: 'Optional[bool]', stream_dependency: 'Optional[int]', weight: 'Optional[int]', fragment: 'Optional[bytes]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, length: 'int', type: 'Frame', flags: 'HeadersFrameFlags', pad_len: 'int', sid: 'int', excl_dependency: 'bool', stream_dependency: 'int', weight: 'int', fragment: 'bytes') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class PriorityFrame(HTTP):
     """Data model for HTTP/2 ``PRIORITY`` frame."""
 
@@ -136,7 +148,8 @@ class PriorityFrame(HTTP):
         def __init__(self, length: 'int', type: 'Frame', flags: 'Literal[None]', sid: 'int', excl_dependency: 'bool', stream_dependency: 'int', weight: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
-class RstStreamFrame(HTTP):
+@info_final
+class RSTStreamFrame(HTTP):
     """Data model for HTTP/2 ``RST_STREAM`` frame."""
 
     #: Flags.
@@ -148,6 +161,7 @@ class RstStreamFrame(HTTP):
         def __init__(self, length: 'int', type: 'Frame', flags: 'Literal[None]', sid: 'int', error: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class SettingsFrameFlags(Flags):
     """Data model for HTTP/2 ``SETTINGS`` frame flags."""
 
@@ -158,6 +172,7 @@ class SettingsFrameFlags(Flags):
         def __init__(self, ACK: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class SettingsFrame(HTTP):
     """Data model for HTTP/2 ``SETTINGS`` frame."""
 
@@ -170,6 +185,7 @@ class SettingsFrame(HTTP):
         def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', sid: 'int', settings: 'OrderedMultiDict[Setting, int]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class PushPromiseFrameFlags(Flags):
     """Data model for HTTP/2 ``PUSH_PROMISE`` frame flags."""
 
@@ -182,6 +198,7 @@ class PushPromiseFrameFlags(Flags):
         def __init__(self, END_HEADERS: 'bool', PADDED: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class PushPromiseFrame(HTTP):
     """Data model for HTTP/2 ``PUSH_PROMISE`` frame."""
 
@@ -192,12 +209,13 @@ class PushPromiseFrame(HTTP):
     #: Promised stream ID.
     promised_sid: 'int'
     #: Header block fragment.
-    fragment: 'Optional[bytes]'
+    fragment: 'bytes'
 
     if TYPE_CHECKING:
-        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', pad_len: 'int', sid: 'int', promised_sid: 'int', fragment: 'Optional[bytes]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', pad_len: 'int', sid: 'int', promised_sid: 'int', fragment: 'bytes') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class PingFrameFlags(Flags):
     """Data model for HTTP/2 ``PING`` frame flags."""
 
@@ -208,6 +226,7 @@ class PingFrameFlags(Flags):
         def __init__(self, ACK: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class PingFrame(HTTP):
     """Data model for HTTP/2 ``PING`` frame."""
 
@@ -220,6 +239,7 @@ class PingFrame(HTTP):
         def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', sid: 'int', data: 'bytes') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class GoawayFrame(HTTP):
     """Data model for HTTP/2 ``GOAWAY`` frame."""
 
@@ -230,12 +250,13 @@ class GoawayFrame(HTTP):
     #: Error code.
     error: 'ErrorCode'
     #: Additional debug data.
-    debug_data: 'Optional[bytes]'
+    debug_data: 'bytes'
 
     if TYPE_CHECKING:
-        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', sid: 'int', last_sid: 'int', error: 'int', debug_data: 'Optional[bytes]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', sid: 'int', last_sid: 'int', error: 'int', debug_data: 'bytes') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class WindowUpdateFrame(HTTP):
     """Data moddel for HTTP/2 ``WINDOW_UPDATE`` frame."""
 
@@ -248,6 +269,7 @@ class WindowUpdateFrame(HTTP):
         def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', sid: 'int', increment: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class ContinuationFrameFlags(Flags):
     """Data model for HTTP/2 ``CONTINUATION`` frame flags."""
 
@@ -258,13 +280,14 @@ class ContinuationFrameFlags(Flags):
         def __init__(self, END_HEADERS: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
+@info_final
 class ContinuationFrame(HTTP):
     """Data model for HTTP/2 ``CONTINUATION`` frame."""
 
     #: Flags.
     flags: 'ContinuationFrameFlags'
     #: Header block fragment.
-    fragment: 'Optional[bytes]'
+    fragment: 'bytes'
 
     if TYPE_CHECKING:
-        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', sid: 'int', fragment: 'Optional[bytes]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, length: 'int', type: 'Frame', flags: 'Optional[Flags]', sid: 'int', fragment: 'bytes') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
