@@ -3,7 +3,8 @@
 
 from typing import TYPE_CHECKING
 
-from pcapkit.corekit.infoclass import Info
+from pcapkit.corekit.infoclass import info_final
+from pcapkit.protocols.data.data import Data
 
 if TYPE_CHECKING:
     from ipaddress import IPv6Address
@@ -16,11 +17,11 @@ if TYPE_CHECKING:
 
 __all__ = [
     'IPv6',
-
 ]
 
 
-class IPv6(Info):
+@info_final
+class IPv6(Data):
     """Data model for Internet Protocol version 6.
 
     Important:
@@ -63,4 +64,4 @@ class IPv6(Info):
         # Thus, we directly inject the information into the annotations.
         self.__annotations__['class'] = int  # pylint: disable=no-member
 
-        return self  # type: ignore[return-value]
+        return self
