@@ -3,7 +3,8 @@
 
 from typing import TYPE_CHECKING
 
-from pcapkit.corekit.infoclass import Info
+from pcapkit.corekit.infoclass import info_final
+from pcapkit.protocols.data.data import Data
 
 if TYPE_CHECKING:
     from pcapkit.const.ipx.packet import Packet
@@ -16,7 +17,8 @@ __all__ = [
 ]
 
 
-class Address(Info):
+@info_final
+class Address(Data):
     """Data model for IPX address."""
 
     #: Network number (``:`` separated).
@@ -32,7 +34,8 @@ class Address(Info):
         def __init__(self, network: 'str', node: 'str', socket: 'Socket', addr: 'str') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements
 
 
-class IPX(Info):
+@info_final
+class IPX(Data):
     """Data model for Internetwork Packet Exchange."""
 
     #: Checksum.
