@@ -3,7 +3,8 @@
 
 from typing import TYPE_CHECKING
 
-from pcapkit.corekit.infoclass import Info
+from pcapkit.corekit.infoclass import info_final
+from pcapkit.protocols.data.data import Data
 
 if TYPE_CHECKING:
     from pcapkit.const.reg.ethertype import EtherType
@@ -11,7 +12,8 @@ if TYPE_CHECKING:
 __all__ = ['Ethernet']
 
 
-class Ethernet(Info):
+@info_final
+class Ethernet(Data):
     """Data model for ethernet packet."""
 
     #: Destination MAC address.
