@@ -3,7 +3,8 @@
 
 from typing import TYPE_CHECKING
 
-from pcapkit.corekit.infoclass import Info
+from pcapkit.corekit.infoclass import info_final
+from pcapkit.protocols.data.data import Data
 
 if TYPE_CHECKING:
     from ipaddress import IPv4Address
@@ -14,7 +15,8 @@ if TYPE_CHECKING:
 __all__ = ['OSPF', 'CrytographicAuthentication']
 
 
-class CrytographicAuthentication(Info):
+@info_final
+class CrytographicAuthentication(Data):
     """Data model for OSPF crytographic authentication."""
 
     #: Key ID.
@@ -28,7 +30,8 @@ class CrytographicAuthentication(Info):
         def __init__(self, key_id: 'int', len: 'int', seq: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,redefined-builtin
 
 
-class OSPF(Info):
+@info_final
+class OSPF(Data):
     """Data model for OSPF packet."""
 
     #: Version number.
