@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-"""data modules for global header of PCAP file"""
+"""data models for global header of PCAP file"""
 
 from typing import TYPE_CHECKING
 
-from pcapkit.corekit.infoclass import Info
+from pcapkit.corekit.infoclass import info_final
+from pcapkit.protocols.data.data import Data
 
 if TYPE_CHECKING:
     from typing_extensions import Literal
@@ -14,7 +15,8 @@ if TYPE_CHECKING:
 __all__ = ['Header', 'MagicNumber']
 
 
-class MagicNumber(Info):
+@info_final
+class MagicNumber(Data):
     """Magic number of PCAP file."""
 
     #: Magic number sequence.
@@ -28,7 +30,8 @@ class MagicNumber(Info):
         def __init__(self, data: 'bytes', byteorder: 'Literal["big", "little"]', nanosecond: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements
 
 
-class Header(Info):
+@info_final
+class Header(Data):
     """Global header of PCAP file."""
 
     #: Magic number.
