@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-"""data modules for raw protocol data"""
+"""data models for raw protocol data"""
 
 from typing import TYPE_CHECKING
 
-from pcapkit.corekit.infoclass import Info
+from pcapkit.corekit.infoclass import info_final
+from pcapkit.protocols.data.data import Data
 
 if TYPE_CHECKING:
     from typing import Optional
@@ -11,7 +12,8 @@ if TYPE_CHECKING:
 __all__ = ['Raw']
 
 
-class Raw(Info):
+@info_final
+class Raw(Data):
     """Raw packet is an unknown protocol."""
 
     #: Original enumeration of this protocol.
