@@ -11,11 +11,12 @@ if TYPE_CHECKING:
     from ipaddress import IPv4Address, IPv6Address
     from typing import Optional, Union
 
+    from pcapkit.const.reg.apptype import AppType
     from pcapkit.const.tcp.checksum import Checksum
+    from pcapkit.const.tcp.flags import Flags as TCP_Flags
     from pcapkit.const.tcp.mp_tcp_option import MPTCPOption
     from pcapkit.const.tcp.option import Option as OptionNumber
     from pcapkit.corekit.multidict import OrderedMultiDict
-    from pcapkit.protocols.transport.tcp import Flags as TCP_Flags
 
     IPAddress = Union[IPv4Address, IPv6Address]
 
@@ -26,8 +27,8 @@ __all__ = [
 
     'Option',
     'UnassignedOption', 'EndOfOptionList', 'NoOperation', 'MaximumSegmentSize', 'WindowScale',
-    'SACKPermitted', 'SACK', 'Echo', 'EchoReply', 'Timestamp', 'PartialOrderConnectionPermitted',
-    'PartialOrderConnectionProfile', 'CC', 'CCNew', 'CCEcho', 'AlternateChecksumRequest',
+    'SACKPermitted', 'SACK', 'Echo', 'EchoReply', 'Timestamps', 'PartialOrderConnectionPermitted',
+    'PartialOrderServiceProfile', 'CC', 'CCNew', 'CCEcho', 'AlternateChecksumRequest',
     'AlternateChecksumData', 'MD5Signature', 'QuickStartResponse', 'UserTimeout',
     'Authentication', 'FastOpenCookie',
 
@@ -47,7 +48,7 @@ class Flags(Data):
     """Data model for TCP flags."""
 
     #: ECN-nonce concealment protection.
-    ns: 'bool'
+    #ns: 'bool'
     #: Congestion window reduced.
     cwr: 'bool'
     #: ECN-Echo.
@@ -66,7 +67,7 @@ class Flags(Data):
     fin: 'bool'
 
     if TYPE_CHECKING:
-        def __init__(self, ns: 'bool', cwr: 'bool', ece: 'bool', urg: 'bool', ack: 'bool', psh: 'bool', rst: 'bool', syn: 'bool', fin: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, cwr: 'bool', ece: 'bool', urg: 'bool', ack: 'bool', psh: 'bool', rst: 'bool', syn: 'bool', fin: 'bool') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
 @info_final
@@ -74,9 +75,9 @@ class TCP(Data):
     """Data model for TCP packet."""
 
     #: Source port.
-    srcport: 'int'
+    srcport: 'AppType'
     #: Destination port.
-    dstport: 'int'
+    dstport: 'AppType'
     #: Sequence number.
     seq: 'int'
     #: Acknowledgment number.
@@ -98,7 +99,7 @@ class TCP(Data):
         #: Connection control flags.
         connection: 'TCP_Flags'
 
-        def __init__(self, srcport: 'int', dstport: 'int', seq: 'int', ack: 'int', hdr_len: 'int', flags: 'Flags', window_size: 'int', checksum: 'bytes', urgent_pointer: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, srcport: 'AppType', dstport: 'AppType', seq: 'int', ack: 'int', hdr_len: 'int', flags: 'Flags', window_size: 'int', checksum: 'bytes', urgent_pointer: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
 class Option(Data):
@@ -214,7 +215,7 @@ class EchoReply(Option):
 
 
 @info_final
-class Timestamp(Option):
+class Timestamps(Option):
     """Data model for TCP timestamp option."""
 
     #: Timestamp .
@@ -235,7 +236,7 @@ class PartialOrderConnectionPermitted(Option):
 
 
 @info_final
-class PartialOrderConnectionProfile(Option):
+class PartialOrderServiceProfile(Option):
     """Data model for TCP partial order connection profile option."""
 
     #: Start flag.
