@@ -40,7 +40,7 @@ if TYPE_CHECKING:
     from typing_extensions import Literal
 
     from pcapkit.corekit.protochain import ProtoChain
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
     from pcapkit.protocols.schema.schema import Schema
 
 __all__ = ['AH']
@@ -226,7 +226,7 @@ class AH(IPsec[Data_AH, Schema_AH],
             **kwargs: Arbitrary keyword arguments.
 
         See Also:
-            For construction argument, please refer to :meth:`make`.
+            For construction argument, please refer to :meth:`self.make <AH.make>`.
 
         """
         #: bool: If the protocol is used as an IPv6 extension header.
