@@ -107,7 +107,7 @@ if TYPE_CHECKING:
     from pcapkit.protocols.data.internet.hopopt import Option as Data_Option
     from pcapkit.protocols.data.internet.hopopt import QuickStartOption as Data_QuickStartOption
     from pcapkit.protocols.data.internet.hopopt import SMFDPDOption as Data_SMFDPDOption
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
     from pcapkit.protocols.schema.internet.hopopt import Option as Schema_Option
     from pcapkit.protocols.schema.internet.hopopt import QuickStartOption as Schema_QuickStartOption
     from pcapkit.protocols.schema.internet.hopopt import SMFDPDOption as Schema_SMFDPDOption
@@ -186,8 +186,8 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
     # Defaults.
     ##########################################################################
 
-    #: DefaultDict[Enum_Option, str | tuple[OptionParser, OptionConstructor]]:
-    #: Option code to method mapping, c.f. :meth:`_read_hopopt_options` and/or
+    #: DefaultDict[Enum_Option, str | tuple[OptionParser, OptionConstructor]]: Option
+    #: code to method mapping, c.f. :meth:`_read_hopopt_options` and/or
     #: :meth:`_make_hopopt_options`. Method names are expected to be referred
     #: to the class by ``_read_opt_${name}`` and/or ``_make_opt_${name}``, and
     #: if such name not found, the value should then be a method that can parse
@@ -492,7 +492,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -577,7 +576,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -612,7 +610,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -653,7 +650,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -718,7 +714,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -782,7 +777,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -842,7 +836,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -906,7 +899,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -951,7 +943,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -1013,7 +1004,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -1046,7 +1036,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -1078,7 +1067,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -1123,7 +1111,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
@@ -1162,7 +1149,6 @@ class HOPOPT(Internet[Data_HOPOPT, Schema_HOPOPT],
 
         Args:
             schema: parsed parameter schema
-            length: option length (incl. type, length, content)
             option: extracted HOPOPT options
 
         Returns:
