@@ -40,7 +40,7 @@ if TYPE_CHECKING:
     from typing_extensions import Literal
 
     from pcapkit.corekit.protochain import ProtoChain
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
     from pcapkit.protocols.schema.schema import Schema
 
 __all__ = ['IPv6_Frag']
@@ -209,7 +209,7 @@ class IPv6_Frag(Internet[Data_IPv6_Frag, Schema_IPv6_Frag],
             **kwargs: Arbitrary keyword arguments.
 
         See Also:
-            For construction argument, please refer to :meth:`make`.
+            For construction argument, please refer to :meth:`self.make <IPv6_Frag.make>`.
 
         """
         #: bool: If the protocol is used as an IPv6 extension header.
