@@ -1,26 +1,40 @@
 # -*- coding: utf-8 -*-
+# mypy: disable-error-code=dict-item
 """Base Protocol
 ===================
 
-:mod:`pcapkit.protocols.link.link` contains :class:`~pcapkit.protocols.link.link.Link`,
-which is a base class for link layer protocols, e.g. :class:`~pcapkit.protocols.link.link.arp.ARP`/InARP,
-:class:`~pcapkit.protocols.link.link.ethernet.Ethernet`, :class:`~pcapkit.protocols.link.link.l2tp.L2TP`,
-:class:`~pcapkit.protocols.link.link.ospf.OSPF`, :class:`~pcapkit.protocols.link.link.rarp.RARP`/DRARP and etc.
+.. module:: pcapkit.protocols.link.link
+
+:mod:`pcapkit.protocols.link.link` contains
+:class:`~pcapkit.protocols.link.link.Link`,
+which is a base class for link layer protocols, e.g.
+:class:`~pcapkit.protocols.link.arp.ARP`/:class:`~pcapkit.protocols.link.arp.InARP`,
+:class:`~pcapkit.protocols.link.ethernet.Ethernet`,
+:class:`~pcapkit.protocols.link.l2tp.L2TP`,
+:class:`~pcapkit.protocols.link.ospf.OSPF`,
+:class:`~pcapkit.protocols.link.rarp.RARP`/:class:`~pcapkit.protocols.link.rarp.DRARP`
+and etc.
 
 """
 import collections
 from typing import TYPE_CHECKING, Generic
 
-from pcapkit.const.reg.ethertype import EtherType as RegType_EtherType
-from pcapkit.protocols.protocol import PT, Protocol
+from pcapkit.const.reg.ethertype import EtherType as Enum_EtherType
+from pcapkit.corekit.module import ModuleDescriptor
+from pcapkit.protocols.protocol import _PT, _ST
+from pcapkit.protocols.protocol import ProtocolBase as Protocol
+from pcapkit.utilities.exceptions import RegistryError
+from pcapkit.utilities.warnings import RegistryWarning, warn
 
 if TYPE_CHECKING:
+    from typing import DefaultDict, Type
+
     from typing_extensions import Literal
 
 __all__ = ['Link']
 
 
-class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
+class Link(Protocol[_PT, _ST], Generic[_PT, _ST]):  # pylint: disable=abstract-method
     """Abstract base class for link layer protocol family.
 
     This class currently supports parsing of the following protocols, which are
@@ -54,22 +68,22 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
     #: Layer of protocol.
     __layer__ = 'Link'  # type: Literal['Link']
 
-    #: DefaultDict[int, tuple[str, str]]: Protocol index mapping for decoding next layer,
+    #: DefaultDict[int, ModuleDescriptor[Protocol] | Type[Protocol]]: Protocol index mapping for decoding next layer,
     #: c.f. :meth:`self._decode_next_layer <pcapkit.protocols.protocol.Protocol._decode_next_layer>`
     #: & :meth:`self._import_next_layer <pcapkit.protocols.protocol.Protocol._import_next_layer>`.
     __proto__ = collections.defaultdict(
-        lambda: ('pcapkit.protocols.misc.raw', 'Raw'),
+        lambda: ModuleDescriptor('pcapkit.protocols.misc.raw', 'Raw'),  # type: ignore[arg-type,return-value]
         {
-            RegType_EtherType.Address_Resolution_Protocol:         ('pcapkit.protocols.link.arp',      'ARP'),
-            RegType_EtherType.Reverse_Address_Resolution_Protocol: ('pcapkit.protocols.link.rarp',     'RARP'),
-            RegType_EtherType.Customer_VLAN_Tag_Type:              ('pcapkit.protocols.link.vlan',     'VLAN'),
-            RegType_EtherType.Internet_Protocol_version_4:         ('pcapkit.protocols.internet.ipv4', 'IPv4'),
-            RegType_EtherType.Internet_Protocol_version_6:         ('pcapkit.protocols.internet.ipv6', 'IPv6'),
+            Enum_EtherType.Address_Resolution_Protocol:         ModuleDescriptor('pcapkit.protocols.link.arp',      'ARP'),
+            Enum_EtherType.Reverse_Address_Resolution_Protocol: ModuleDescriptor('pcapkit.protocols.link.rarp',     'RARP'),
+            Enum_EtherType.Customer_VLAN_Tag_Type:              ModuleDescriptor('pcapkit.protocols.link.vlan',     'VLAN'),
+            Enum_EtherType.Internet_Protocol_version_4:         ModuleDescriptor('pcapkit.protocols.internet.ipv4', 'IPv4'),
+            Enum_EtherType.Internet_Protocol_version_6:         ModuleDescriptor('pcapkit.protocols.internet.ipv6', 'IPv6'),
 
             # c.f., https://en.wikipedia.org/wiki/EtherType#Values
-            0x8137: ('pcapkit.protocols.internet.ipx',  'IPX'),
+            0x8137:                                             ModuleDescriptor('pcapkit.protocols.internet.ipx',  'IPX'),
         },
-    )
+    )  # type: DefaultDict[int | Enum_EtherType, ModuleDescriptor[Protocol] | Type[Protocol]]
 
     ##########################################################################
     # Properties.
@@ -86,26 +100,32 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
     ##########################################################################
 
     @classmethod
-    def register(cls, code: 'RegType_EtherType', module: str, class_: str) -> 'None':
+    def register(cls, code: 'Enum_EtherType', protocol: 'ModuleDescriptor[Protocol] | Type[Protocol]') -> 'None':  # type: ignore[override]
         r"""Register a new protocol class.
 
         Notes:
             The full qualified class name of the new protocol class
-            should be as ``{module}.{class_}``.
+            should be as ``{protocol.module}.{protocol.name}``.
 
         Arguments:
             code: protocol code as in :class:`~pcapkit.const.reg.ethertype.EtherType`
-            module: module name
-            class\_: class name
+            protocol: module descriptor or a
+                :class:`~pcapkit.protocols.protocol.Protocol` subclass
 
         """
-        cls.__proto__[code] = (module, class_)
+        if isinstance(protocol, ModuleDescriptor):
+            protocol = protocol.klass
+        if not issubclass(protocol, Protocol):
+            raise RegistryError(f'protocol must be a Protocol subclass, not {protocol!r}')
+        if code in cls.__proto__:
+            warn(f'protocol {code} already registered, overwriting', RegistryWarning)
+        cls.__proto__[code] = protocol
 
     ##########################################################################
     # Utilities.
     ##########################################################################
 
-    def _read_protos(self, size: int) -> 'RegType_EtherType':
+    def _read_protos(self, size: int) -> 'Enum_EtherType':
         """Read next layer protocol type.
 
         Arguments:
@@ -116,5 +136,5 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
 
         """
         _byte = self._read_unpack(size)
-        _prot = RegType_EtherType.get(_byte)
+        _prot = Enum_EtherType.get(_byte)
         return _prot
