@@ -3,6 +3,8 @@
 """Auxiliary Protocols
 =========================
 
+.. module:: pcapkit.protocols.misc
+
 :mod:`pcapkit.protocols.misc` contains the auxiliary protocol implementations.
 Such includes the :class:`~pcapkit.protocols.misc.raw.Raw` class for not-supported
 protocols, the :class:`~pcapkit.protocols.misc.null.NoPayload` class for
@@ -13,6 +15,9 @@ indication of empty payload, and PCAP header classes.
 # PCAP Headers
 from pcapkit.protocols.misc.pcap import *
 
+# PCAPNG Format
+from pcapkit.protocols.misc.pcapng import *
+
 # Miscellaneous Classes for Protocols
 from pcapkit.protocols.misc.raw import Raw
 from pcapkit.protocols.misc.null import NoPayload
@@ -21,6 +26,9 @@ __all__ = [
     # PCAP Headers
     'Header', 'Frame',
 
+    # PCAPNG Format
+    'PCAPNG',
+
     # No Payload
     'NoPayload',
 
