@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# mypy: disable-error-code=dict-item
 """Root Protocol
 ===================
 
@@ -15,7 +16,6 @@ import collections
 import contextlib
 import enum
 import functools
-import importlib
 import io
 import os
 import shutil
@@ -23,12 +23,12 @@ import string
 import struct
 import textwrap
 import urllib.parse
-from typing import TYPE_CHECKING, Generic, TypeVar, cast, overload
+from typing import TYPE_CHECKING, Any, Generic, Optional, Type, TypeVar, cast, overload
 
 import aenum
 import chardet
 
-from pcapkit.corekit.infoclass import Info
+from pcapkit.corekit.module import ModuleDescriptor
 from pcapkit.corekit.protochain import ProtoChain
 from pcapkit.protocols import data as data_module
 from pcapkit.protocols import schema as schema_module
@@ -41,6 +41,7 @@ from pcapkit.utilities.compat import cached_property
 from pcapkit.utilities.decorators import beholder, seekset
 from pcapkit.utilities.exceptions import (ProtocolNotFound, ProtocolNotImplemented, RegistryError,
                                           StructError, UnsupportedCall)
+from pcapkit.utilities.warnings import RegistryWarning, warn
 
 if TYPE_CHECKING:
     from enum import IntEnum as StdlibEnum
@@ -49,38 +50,54 @@ if TYPE_CHECKING:
     from aenum import IntEnum as AenumEnum
     from typing_extensions import Literal, Self
 
-__all__ = ['Protocol']
+__all__ = ['ProtocolBase']
 
-PT = TypeVar('PT', bound='Data')
-ST = TypeVar('ST', bound='Schema')
+_PT = TypeVar('_PT', bound='Data')
+_ST = TypeVar('_ST', bound='Schema')
 
 # readable characters' order list
 readable = [ord(char) for char in filter(lambda char: not char.isspace(), string.printable)]
 
 
-class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
-    """Abstract base class for all protocol family."""
+class ProtocolMeta(abc.ABCMeta):
+    """Meta class to add dynamic support to :class:`Protocol`.
+
+    This meta class is used to generate necessary attributes for the
+    :class:`Protocol` class. It can be useful to reduce unnecessary
+    registry calls and simplify the customisation process.
+
+    """
+
+
+class ProtocolBase(Generic[_PT, _ST], metaclass=ProtocolMeta):
+    """Abstract base class for all protocol family.
+
+    Note:
+        This class is for internal use only. For customisation, please use
+        :class:`Protocol` instead.
+
+    """
 
     if TYPE_CHECKING:
         #: Parsed packet data.
-        _info: 'PT'
+        _info: '_PT'
         #: Raw packet data.
         _data: 'bytes'
         #: Source packet stream.
         _file: 'IO[bytes]'
         #: Next layer protocol instance.
-        _next: 'Protocol'
+        _next: 'ProtocolBase'
         #: Protocol chain instance.
         _protos: 'ProtoChain'
 
         # Internal data storage for cached properties.
         __cached__: 'dict[str, Any]'
         #: Protocol packet data definition.
-        __data__: 'Type[PT]'
+        __data__: 'Type[_PT]'
         #: Protocol header schema definition.
-        __schema__: 'Type[ST]'
+        __schema__: 'Type[_ST]'
         #: Protocol header schema instance.
-        __header__: 'ST'
+        __header__: '_ST'
 
     ##########################################################################
     # Defaults.
@@ -88,17 +105,18 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
     #: Layer of protocol, can be one of ``Link``, ``Internet``, ``Transport``
     #: and ``Application``. For example, the layer of
-    #: :class:`~pcapkit.protocols.link.Ethernet` is ``Link``. However, certain
-    #: protocols are not in any layer, such as
-    # :class:`~pcapkit.protocols.misc.raw.Raw`, and thus its layer is :obj:`None`.
+    #: :class:`~pcapkit.protocols.link.ethernet.Ethernet` is ``Link``. However,
+    #: certain protocols are not in any layer, such as
+    #: :class:`~pcapkit.protocols.misc.raw.Raw`, and thus its layer is :obj:`None`.
     __layer__: 'Optional[Literal["Link", "Internet", "Transport", "Application"]]' = None
 
     #: Protocol index mapping for decoding next layer, c.f.
-    # :meth:`self._decode_next_layer <pcapkit.protocols.protocol.Protocol._decode_next_layer>`
+    #: :meth:`self._decode_next_layer <pcapkit.protocols.protocol.Protocol._decode_next_layer>`
     #: & :meth:`self._import_next_layer <pcapkit.protocols.protocol.Protocol._import_next_layer>`.
-    #: The values should be a tuple representing the module name and class name.
-    __proto__: 'DefaultDict[int, tuple[str, str]]' = collections.defaultdict(
-        lambda: ('pcapkit.protocols.misc.raw', 'Raw'),
+    #: The values should be a tuple representing the module name and class name,
+    #: or a :class:`Protocol` subclass.
+    __proto__: 'DefaultDict[int, ModuleDescriptor[ProtocolBase] | Type[ProtocolBase]]' = collections.defaultdict(
+        lambda: ModuleDescriptor('pcapkit.protocols.misc.raw', 'Raw'),
     )
 
     ##########################################################################
@@ -125,7 +143,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
     # info dict of current instance
     @property
-    def info(self) -> 'PT':
+    def info(self) -> '_PT':
         """Info dict of current instance."""
         return self._info
 
@@ -143,7 +161,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
     # payload of current instance
     @property
-    def payload(self) -> 'Protocol':
+    def payload(self) -> 'ProtocolBase':
         """Payload of current instance."""
         return self._next
 
@@ -175,7 +193,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
     # schema data
     @cached_property
-    def schema(self) -> 'ST':
+    def schema(self) -> '_ST':
         """Schema data of the protocol."""
         return self.__header__
 
@@ -187,8 +205,9 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
     def id(cls) -> 'tuple[str, ...]':
         """Index ID of the protocol.
 
-        By default, it returns the name of the protocol. In certain cases, the
-        method may return multiple values.
+        Returns:
+            By default, it returns the name of the protocol. In certain cases,
+            the method may return multiple values.
 
         See Also:
             :meth:`pcapkit.protocols.protocol.Protocol.__getitem__`
@@ -197,7 +216,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         return (cls.__name__,)
 
     @abc.abstractmethod
-    def read(self, length: 'Optional[int]' = None, **kwargs: 'Any') -> 'PT':
+    def read(self, length: 'Optional[int]' = None, **kwargs: 'Any') -> '_PT':
         """Read (parse) packet data.
 
         Args:
@@ -210,7 +229,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         """
 
     @abc.abstractmethod
-    def make(self, **kwargs: 'Any') -> 'ST':
+    def make(self, **kwargs: 'Any') -> '_ST':
         """Make (construct) packet data.
 
         Args:
@@ -240,7 +259,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         packet = kwargs.get('__packet__', {})  # packet data
         return self.__header__.pack(packet)
 
-    def unpack(self, length: 'Optional[int]' = None, **kwargs: 'Any') -> 'PT':
+    def unpack(self, length: 'Optional[int]' = None, **kwargs: 'Any') -> '_PT':
         """Unpack (parse) packet data.
 
         Args:
@@ -256,9 +275,9 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             the packet data is not available in the current instance.
 
         """
-        if cast('Optional[ST]', self.__header__) is None:
+        if cast('Optional[_ST]', self.__header__) is None:
             packet = kwargs.get('__packet__', {})  # packet data
-            self.__header__ = cast('ST', self.__schema__.unpack(self._file, length, packet))  # type: ignore[call-arg,misc]
+            self.__header__ = cast('_ST', self.__schema__.unpack(self._file, length, packet))  # type: ignore[call-arg,misc]
         return self.read(length, **kwargs)
 
     @staticmethod
@@ -320,7 +339,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             return url.replace('%', r'\x').encode().decode('unicode_escape', errors='replace')
 
     @staticmethod
-    def expand_comp(value: 'str | Protocol | Type[Protocol]') -> 'tuple':
+    def expand_comp(value: 'str | ProtocolBase | Type[ProtocolBase]') -> 'tuple':
         """Expand protocol class to protocol name.
 
         The method is used to expand protocol class to protocol name, in the
@@ -341,9 +360,9 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             value: Protocol class or name.
 
         """
-        if isinstance(value, type) and issubclass(value, Protocol):
+        if isinstance(value, type) and issubclass(value, ProtocolBase):
             comp = (value, *(name.upper() for name in value.id()))
-        elif isinstance(value, Protocol):
+        elif isinstance(value, ProtocolBase):
             comp = (type(value), *(name.upper() for name in value.id()))
         else:
             from pcapkit.protocols import __proto__ as protocols_registry  # pylint: disable=import-outside-toplevel # isort: skip
@@ -355,7 +374,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         return comp
 
     @classmethod
-    def analyze(cls, proto: 'int', payload: 'bytes', **kwargs: 'Any') -> 'Protocol':
+    def analyze(cls, proto: 'int', payload: 'bytes', **kwargs: 'Any') -> 'ProtocolBase':
         """Analyse packet payload.
 
         Args:
@@ -368,8 +387,10 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             instance.
 
         """
-        module, name = cls.__proto__[proto]
-        protocol = cast('Type[Protocol]', getattr(importlib.import_module(module), name))
+        protocol = cls.__proto__[proto]
+        if isinstance(protocol, ModuleDescriptor):
+            protocol = protocol.klass
+            cls.__proto__[proto] = protocol  # update mapping upon import
 
         payload_io = io.BytesIO(payload)
         try:
@@ -388,26 +409,29 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         return report
 
     @classmethod
-    def register(cls, code: 'int', module: 'str', class_: 'str') -> 'None':
+    def register(cls, code: 'int', protocol: 'ModuleDescriptor | Type[ProtocolBase]') -> 'None':
         r"""Register a new protocol class.
 
         Notes:
             The full qualified class name of the new protocol class
-            should be as ``{module}.{class_}``.
+            should be as ``{protocol.module}.{protocol.name}``.
 
         Arguments:
             code: protocol code
-            module: module name
-            class\_: class name
+            protocol: module descriptor or a
+                :class:`~pcapkit.protocols.protocol.Protocol` subclass
 
         """
-        protocol = getattr(importlib.import_module(module), class_)
-        if not issubclass(protocol, Protocol):
-            raise RegistryError('protocol must be a Protocol subclass')
-        cls.__proto__[code] = (module, class_)
+        if isinstance(protocol, ModuleDescriptor):
+            protocol = protocol.klass
+        if not issubclass(protocol, ProtocolBase):
+            raise RegistryError(f'protocol must be a Protocol subclass, not {protocol!r}')
+        if code in cls.__proto__:
+            warn(f'protocol {code} already registered, overwriting', RegistryWarning)
+        cls.__proto__[code] = protocol
 
     @classmethod
-    def from_schema(cls, schema: 'ST | dict[str, Any]') -> 'Self':
+    def from_schema(cls, schema: '_ST | dict[str, Any]') -> 'Self':
         """Create protocol instance from schema.
 
         Args:
@@ -418,7 +442,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
         """
         if not isinstance(schema, Schema):
-            schema = cast('ST', cls.__schema__.from_dict(schema))
+            schema = cast('_ST', cls.__schema__.from_dict(schema))
 
         self = cls.__new__(cls)
         self.__header__ = schema
@@ -429,7 +453,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         return self
 
     @classmethod
-    def from_data(cls, data: 'PT | dict[str, Any]') -> 'Self':
+    def from_data(cls, data: '_PT | dict[str, Any]') -> 'Self':
         """Create protocol instance from data.
 
         Args:
@@ -440,7 +464,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
         """
         if not isinstance(data, Data):
-            data = cast('PT', cls.__data__.from_dict(data))
+            data = cast('_PT', cls.__data__.from_dict(data))
 
         self = cls.__new__(cls)
         kwargs = self._make_data(data)
@@ -477,7 +501,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             length: Length of packet data.
             _layer (str): Parse packet until ``_layer``
                 (:attr:`self._exlayer <pcapkit.protocols.protocol.Protocol._exlayer>`).
-            _protocol (str | Protocol | Type[Protocol]): Parse packet until ``_protocol``
+            _protocol (Union[str, Protocol, Type[Protocol]]): Parse packet until ``_protocol``
                 (:attr:`self._exproto <pcapkit.protocols.protocol.Protocol._exproto>`).
             **kwargs: Arbitrary keyword arguments.
 
@@ -489,13 +513,16 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         #: str: Parse packet until such layer.
         self._exlayer = kwargs.pop('_layer', None)  # type: Optional[str]
         #: str: Parse packet until such protocol.
-        self._exproto = kwargs.pop('_protocol', None)  # type: Optional[str | Protocol | Type[Protocol]]
+        self._exproto = kwargs.pop('_protocol', None)  # type: Optional[str | ProtocolBase | Type[ProtocolBase]]
         #: bool: If terminate parsing next layer of protocol.
         self._sigterm = self._check_term_threshold()
 
         # post-init customisations
         self.__post_init__(file, length, **kwargs)  # type: ignore[arg-type]
 
+        # inject packet payload to the info dict
+        self._info.__update__(packet=self.packet.payload)
+
     @overload
     def __post_init__(self, file: 'IO[bytes] | bytes', length: 'Optional[int]' = ..., **kwargs: 'Any') -> 'None': ...
     @overload
@@ -527,13 +554,14 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         #: pcapkit.protocols.data.data.Data: Parsed packet data.
         self._info = self.unpack(length, **kwargs)
 
-    def __init_subclass__(cls, /, schema: 'Optional[Type[ST]]' = None,
-                          data: 'Optional[Type[PT]]' = None, **kwargs: 'Any') -> 'None':
+    def __init_subclass__(cls, /, schema: 'Optional[Type[_ST]]' = None,
+                          data: 'Optional[Type[_PT]]' = None, *args: 'Any', **kwargs: 'Any') -> 'None':
         """Initialisation for subclasses.
 
         Args:
             schema: Schema class.
             data: Data class.
+            *args: Arbitrary positional arguments.
             **kwargs: Arbitrary keyword arguments.
 
         This method is called when a subclass of :class:`Protocol` is defined.
@@ -549,12 +577,12 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             :class:`~pcapkit.protocols.data.data.Data_Raw` classes will be used.
 
         """
-        super().__init_subclass__(**kwargs)
+        super().__init_subclass__()
 
         if schema is None:
-            schema = cast('Type[ST]', getattr(schema_module, cls.__name__, Schema_Raw))
+            schema = cast('Type[_ST]', getattr(schema_module, cls.__name__, Schema_Raw))
         if data is None:
-            data = cast('Type[PT]', getattr(data_module, cls.__name__, Data_Raw))
+            data = cast('Type[_PT]', getattr(data_module, cls.__name__, Data_Raw))
 
         cls.__schema__ = schema
         cls.__data__ = data
@@ -570,17 +598,8 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         if (cached := self.__cached__.get('__repr__')) is not None:
             return cached
 
-        name = type(self).__name__
-        temp = []  # type: list[str]
-        for (key, value) in self._info.items():
-            if isinstance(value, Info):
-                temp.append(f'{key}=...')
-            else:
-                temp.append(f'{key}={value!r}')
-        args = ', '.join(temp)
-
         # cache and return
-        repr_ = f'<{name} alias={self.alias!r} {self.info_name}=({args})>'
+        repr_ = f'<{self.alias} {self.info_name}={self._info!r}>'
 
         self.__cached__['__repr__'] = repr_
         return repr_
@@ -638,11 +657,11 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         """Iterate through :attr:`self._data <pcapkit.protocols.protocol.Protocol._data>`."""
         return io.BytesIO(self._data)
 
-    def __getitem__(self, key: 'str | Protocol | Type[Protocol]') -> 'Protocol':
+    def __getitem__(self, key: 'str | Protocol | Type[Protocol]') -> 'ProtocolBase':
         """Subscription (``getitem``) support.
 
         * If ``key`` is a :class:`~pcapkit.protocols.protocol.Protocol` object,
-          the method will fetch its indexes (:meth:`~pcapkit.protocols.protocol.Protocol.id`).
+          the method will fetch its indexes (:meth:`self.id <pcapkit.protocols.protocol.Protocol.id>`).
         * Later, search the packet's chain of protocols with the calculated ``key``.
         * If no matches, then raises :exc:`~pcapkit.utilities.exceptions.ProtocolNotFound`.
 
@@ -726,9 +745,9 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             other: Comparision against the object.
 
         """
-        if isinstance(other, type) and issubclass(other, Protocol):
+        if isinstance(other, type) and issubclass(other, ProtocolBase):
             return cls is other
-        if isinstance(other, Protocol):
+        if isinstance(other, ProtocolBase):
             return cls.id() == other.id()
 
         if isinstance(other, str):
@@ -745,13 +764,13 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
     ##########################################################################
 
     def _get_payload(self) -> 'bytes':
-        """Get payload of :attr:`self.__header__ <Protocol.__header__>`.
+        """Get payload from :attr:`self.__header__ <Protocol.__header__>`.
 
         Returns:
             Payload of :attr:`self.__header__ <Protocol.__header__>` as :obj:`bytes`.
 
         See Also:
-            This is a wrapper function for :meth:`pcapkit.protocols.schema.Schema.get_payload`.
+            This is a wrapper function for :meth:`pcapkit.protocols.schema.schema.Schema.get_payload`.
 
         """
         return self.__header__.get_payload()
@@ -868,7 +887,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         * If ``discard`` is set as :data:`True`, returns the packet body (in
           :obj:`bytes`) only.
         * Otherwise, returns the header and payload data as
-          :class:`~pcapkit.protocols.data.protocol.Data_Packet` object.
+          :class:`~pcapkit.protocols.data.protocol.Packet` object.
 
         """
         if header is not None:
@@ -1036,7 +1055,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         return data.to_dict()
 
     @classmethod
-    def _make_payload(cls, data: 'Data') -> 'Protocol':
+    def _make_payload(cls, data: 'Data') -> 'ProtocolBase':
         """Create payload from ``data`` for protocol construction.
 
         This method uses ``__next_type__`` and ``__next_name__`` to
@@ -1053,7 +1072,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
         """
         proto = cast('Optional[Type[Protocol]]', data.get('__next_type__'))
-        if proto is None or not (isinstance(proto, type) and issubclass(proto, Protocol)):
+        if proto is None or not (isinstance(proto, type) and issubclass(proto, ProtocolBase)):
             from pcapkit.protocols.misc.null import \
                 NoPayload  # pylint: disable=import-outside-toplevel
             return NoPayload()
@@ -1066,15 +1085,15 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
         return proto.from_data(data[name])
 
-    def _decode_next_layer(self, dict_: 'PT', proto: 'int', length: 'Optional[int]' = None, *,
-                           packet: 'Optional[dict[str, Any]]' = None) -> 'PT':
+    def _decode_next_layer(self, dict_: '_PT', proto: 'int', length: 'Optional[int]' = None, *,
+                           packet: 'Optional[dict[str, Any]]' = None) -> '_PT':
         r"""Decode next layer protocol.
 
         Arguments:
             dict\_: info buffer
             proto: next layer protocol index
             length: valid (*non-padding*) length
-            packet: packet info (passed from :meth:`unpack`)
+            packet: packet info (passed from :meth:`self.unpack <Protocol.unpack>`)
 
         Returns:
             Current protocol with next layer extracted.
@@ -1086,7 +1105,7 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
             be included when :meth:`Info.to_dict <pcapkit.corekit.infoclass.Info.to_dict>` is called.
 
         """
-        next_ = cast('Protocol', self._import_next_layer(proto, length, packet=packet))  # type: ignore[misc,call-arg,redundant-cast]
+        next_ = cast('ProtocolBase', self._import_next_layer(proto, length, packet=packet))  # type: ignore[misc,call-arg,redundant-cast]
         info, chain = next_.info, next_.protochain
 
         # make next layer protocol name
@@ -1105,20 +1124,20 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
 
     @beholder
     def _import_next_layer(self, proto: 'int', length: 'Optional[int]' = None, *,
-                           packet: 'Optional[dict[str, Any]]' = None) -> 'Protocol':
+                           packet: 'Optional[dict[str, Any]]' = None) -> 'ProtocolBase':
         """Import next layer extractor.
 
         Arguments:
             proto: next layer protocol index
             length: valid (*non-padding*) length
-            packet: packet info (passed from :meth:`unpack`)
+            packet: packet info (passed from :meth:`self.unpack <Protocol.unpack>`)
 
         Returns:
             Instance of next layer.
 
         """
         if TYPE_CHECKING:
-            protocol: 'Type[Protocol]'
+            protocol: 'Type[ProtocolBase]'
 
         file_ = self._get_payload()
         if length is None:
@@ -1129,8 +1148,10 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
         elif self._sigterm:
             from pcapkit.protocols.misc.raw import Raw as protocol  # isort: skip # pylint: disable=import-outside-toplevel
         else:
-            module, name = self.__proto__[proto]
-            protocol = cast('Type[Protocol]', getattr(importlib.import_module(module), name))
+            protocol = self.__proto__[proto]  # type: ignore[assignment]
+            if isinstance(protocol, ModuleDescriptor):
+                protocol = protocol.klass  # type: ignore[unreachable]
+                self.__proto__[proto] = protocol  # update mapping upon import
 
         next_ = protocol(file_, length, alias=proto, packet=packet,
                          layer=self._exlayer, protocol=self._exproto)  # type: ignore[abstract]
@@ -1154,3 +1175,42 @@ class Protocol(Generic[PT, ST], metaclass=abc.ABCMeta):
                     break
 
         return layer_match or protocol_match
+
+
+class Protocol(ProtocolBase, Generic[_PT, _ST]):
+    """Abstract base class for all protocol family."""
+
+    def __init_subclass__(cls, /, schema: 'Optional[Type[_ST]]' = None,
+                          data: 'Optional[Type[_PT]]' = None, *args: 'Any', **kwargs: 'Any') -> 'None':
+        """Initialisation for subclasses.
+
+        Args:
+            schema: Schema class.
+            data: Data class.
+            *args: Arbitrary positional arguments.
+            **kwargs: Arbitrary keyword arguments.
+
+        This method is called when a subclass of :class:`Protocol` is defined.
+        It is used to set the :attr:`self.__schema__ <pcapkit.protocols.protocol.Protocol.__schema__>`
+        attribute of the subclass.
+
+        Notes:
+            When ``schema`` and/or ``data`` is not specified, the method will first
+            try to find the corresponding class in the
+            :mod:`~pcapkit.protocols.schema` and :mod:`~pcapkit.protocols.data`
+            modules respectively. If the class is not found, the default
+            :class:`~pcapkit.protocols.schema.schema.Schema_Raw` and
+            :class:`~pcapkit.protocols.data.data.Data_Raw` classes will be used.
+
+        This method also registers the subclass to the protocol registry,
+        i.e., :attr:`pcapkit.protocols.__proto__`.
+
+        See Also:
+            For more information on the registry, please refer to
+            :func:`pcapkit.foundation.registry.protocols.register_protocol`.
+
+        """
+        from pcapkit.foundation.registry.protocols import register_protocol
+        register_protocol(cls)
+
+        return super().__init_subclass__(schema, data, *args, **kwargs)
