@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 """schema for protocol headers"""
 
+import abc
 import collections
 import collections.abc
 import io
 import itertools
-from typing import TYPE_CHECKING, Generic, TypeVar, cast, final
+import sys
+from typing import TYPE_CHECKING, Any, Generic, TypeVar, cast, final
 
 from pcapkit.corekit.fields.collections import ListField, OptionField
-from pcapkit.corekit.fields.field import NoValue, _Field
+from pcapkit.corekit.fields.field import FieldBase, NoValue
 from pcapkit.corekit.fields.misc import ConditionalField, ForwardMatchField, PayloadField
 from pcapkit.corekit.fields.strings import PaddingField
 from pcapkit.corekit.infoclass import FinalisedState
@@ -19,17 +21,19 @@ from pcapkit.utilities.warnings import SchemaWarning, UnknownFieldWarning, warn
 
 if TYPE_CHECKING:
     from collections import OrderedDict
-    from typing import IO, Any, Iterable, Iterator, Optional, Type
+    from enum import Enum
+    from typing import IO, Any, Callable, DefaultDict, Iterable, Iterator, Optional, Type
 
     from typing_extensions import Self
 
-__all__ = ['Schema', 'schema_final']
+__all__ = ['Schema', 'EnumSchema', 'schema_final']
 
-VT = TypeVar('VT')
-ST = TypeVar('ST', bound='Type[Schema]')
+_VT = TypeVar('_VT')
+_ET = TypeVar('_ET', bound='Enum')
+_ST = TypeVar('_ST', bound='Type[Schema]')
 
 
-def schema_final(cls: 'ST', *, _finalised: 'bool' = True) -> 'ST':
+def schema_final(cls: '_ST', *, _finalised: 'bool' = True) -> '_ST':
     """Finalise schema class.
 
     This decorator function is used to generate necessary
@@ -37,6 +41,11 @@ def schema_final(cls: 'ST', *, _finalised: 'bool' = True) -> 'ST':
     class. It can be useful to reduce runtime generation
     time as well as caching already generated attributes.
 
+    Notes:
+        The decorator should only be used on the *final*
+        class, otherwise, any subclasses derived from a
+        finalised schema class will not be re-finalised.
+
     Args:
         cls: Schema class.
         _finalised: Whether to make the schema class finalised.
@@ -44,11 +53,6 @@ def schema_final(cls: 'ST', *, _finalised: 'bool' = True) -> 'ST':
     Returns:
         Finalised schema class.
 
-    Notes:
-        The decorator should only be used on the *final*
-        class, otherwise, any subclasses derived from a
-        finalised schema class will not be re-finalised.
-
     :meta decorator:
     """
     if cls.__finalised__ == FinalisedState.FINAL:
@@ -65,50 +69,8 @@ def schema_final(cls: 'ST', *, _finalised: 'bool' = True) -> 'ST':
     cls.__builtin__ = set(temp)
     cls.__excluded__.extend(cls.__builtin__)
 
-    args_ = []  # type: list[str]
-    dict_ = []  # type: list[str]
-
-    cls_fields = []  # type: list[tuple[str, _Field]]
-    for cls_ in cls.mro():
-        # NOTE: We skip the ``Schema`` class itself, to avoid superclass
-        # type annotations being considered.
-        if cls_ is Schema:
-            break
-
-        # NOTE: We iterate in reversed order to ensure that the type
-        # annotations of the superclasses are considered first.
-        for key in reversed(cls_.__dict__.keys()):
-            # NOTE: We skip duplicated annotations to avoid duplicate
-            # argument in function definition.
-            if key in args_:
-                continue
-
-            # NOTE: We only consider the fields that are instances of
-            # the ``_Field`` class.
-            field = cls_.__dict__[key]
-            if not isinstance(field, _Field):
-                continue
-
-            # NOTE: We need to consider the case where the field itself
-            # is optional, i.e., the field is not required to be present
-            # in the protocol header.
-            args_.append(f'{key}=NoValue')
-            dict_.append(f'{key}={key}')
-
-            field.name = key
-            cls_fields.append((key, field))
-
-    # NOTE: We reverse the two lists such that the order of the
-    # arguments is the same as the order of the field definition,
-    # i.e., from the most base class to the most derived class.
-    args_.reverse()
-    dict_.reverse()
-
-    # NOTE: We also reverse the field list such that the order
-    # can be preserved in the :class:`~collections.OrderedDict`
-    # instance.
-    cls_fields.reverse()
-    cls.__fields__ = collections.OrderedDict(cls_fields)
+    args_ = [f'{key}=NoValue' for key in cls.__fields__]
+    dict_ = [f'{key}={key}' for key in cls.__fields__]
 
     # NOTE: We shall only attempt to generate ``__init__`` method
     # if the class does not define such method.
@@ -148,7 +110,116 @@ def schema_final(cls: 'ST', *, _finalised: 'bool' = True) -> 'ST':
     return final(cls)
 
 
-class Schema(Mapping[str, VT], Generic[VT]):
+class SchemaMeta(abc.ABCMeta):
+    """Meta class to add dynamic support to :class:`Schema`.
+
+    This meta class is used to generate necessary attributes for the
+    :class:`Schema` class. It can be useful to reduce runtime generation
+    cost as well as caching already generated attributes.
+
+    * :attr:`Schema.__fields__` is a dictionary of field names and their
+      corresponding :class:`~pcapkit.corekit.fields.field.Field` objects,
+      which are used to define and parse the protocol headers. The field
+      dictionary will automatically be populated from the class attributes
+      of the :class:`Schema` class, and the field names will be the same
+      as the attribute names.
+
+      .. seealso::
+
+         This is implemented thru setting up the initial field dictionary
+         in the |prepare|_ method, and then inherit the field
+         dictionaries from the base classes.
+
+         Later, during the class creation, the
+         :meth:`Field.__set_name__ <pcapkit.corekit.fields.field.FieldBase.__set_name__>`
+         method will be called to set the field name for each field object,
+         as well as to add the field object to the field dictionary.
+
+         .. |prepare| replace:: :meth:`__prepare__`
+         .. _prepare: https://docs.python.org/3/reference/datamodel.html#preparing-the-class-namespace
+
+    * :attr:`Schema.__additional__` and :attr:`Schema.__excluded__` are
+      lists of additional and excluded field names, which are used to
+      determine certain names to be included or excluded from the field
+      dictionary. They will be automatically populated from the class
+      attributes of the :class:`Schema` class and its base classes.
+
+      .. note::
+
+         This is implemented thru the :meth:`~object.__new__` method, which
+         will inherit the additional and excluded field names from the base
+         classes, as well as populating the additional and excluded field
+         from the subclass attributes.
+
+         .. code-block:: python
+
+            class A(Schema):
+                __additional__ = ['a', 'b']
+
+            class B(A):
+                __additional__ = ['c', 'd']
+
+            class C(B):
+                __additional__ = ['e', 'f']
+
+            print(A.__additional__)  # ['a', 'b']
+            print(B.__additional__)  # ['a', 'b', 'c', 'd']
+            print(C.__additional__)  # ['a', 'b', 'c', 'd', 'e', 'f']
+
+    """
+
+    @classmethod
+    def __prepare__(cls, name: 'str', bases: 'tuple[type, ...]', /, **kwds: 'Any') -> 'Mapping[str, object]':
+        """Prepare the namespace for the schema class.
+
+        Args:
+            name: Name of the schema class.
+            bases: Base classes of the schema class.
+            **kwds: Additional keyword arguments at class definition.
+
+        This method is used to create the initial field dictionary
+        :attr:`~Schema.__fields__` for the schema class.
+
+        """
+        fields = collections.OrderedDict()
+        for base in bases:
+            if hasattr(base, '__fields__'):
+                fields.update(base.__fields__)
+        return collections.OrderedDict(__fields__=fields)
+
+    def __new__(cls, name: 'str', bases: 'tuple[type, ...]', attrs: 'dict[str, Any]', **kwargs: 'Any') -> 'Type[Schema]':
+        """Create the schema class.
+
+        Args:
+            name: Schema class name.
+            bases: Schema class bases.
+            attrs: Schema class attributes.
+            **kwargs: Arbitrary keyword arguments in class definition.
+
+        This method is used to inherit the :attr:`~Schema.__additional__` and
+        :attr:`~Schema.__excluded__` fields from the base classes, as well as
+        populating both fields from the subclass attributes.
+
+        """
+        if '__additional__' not in attrs:
+            attrs['__additional__'] = []
+        if '__excluded__' not in attrs:
+            attrs['__excluded__'] = []
+
+        for base in bases:
+            if hasattr(base, '__additional__'):
+                attrs['__additional__'].extend(name for name in base.__additional__ if name not in attrs['__additional__'])
+            if hasattr(base, '__excluded__'):
+                attrs['__excluded__'].extend(name for name in base.__excluded__ if name not in attrs['__excluded__'])
+
+        # NOTE: for unknown reason, the following code will cause an error
+        # for duplicated keyword arguments in class definition.
+        if sys.version_info < (3, 11):
+            return type.__new__(cls, name, bases, attrs, **kwargs)
+        return super().__new__(cls, name, bases, attrs, **kwargs)  # type: ignore[return-value]
+
+
+class Schema(Mapping[str, _VT], Generic[_VT], metaclass=SchemaMeta):
     """Schema for protocol headers."""
 
     if TYPE_CHECKING:
@@ -161,7 +232,7 @@ class Schema(Mapping[str, VT], Generic[VT]):
         #: List of builtin methods.
         __builtin__: 'set[str]'
         #: Mapping of fields.
-        __fields__: 'OrderedDict[str, _Field]'
+        __fields__: 'OrderedDict[str, FieldBase]'
         #: Mapping of field names to packed values.
         __buffer__: 'dict[str, bytes]'
         #: Flag for whether the schema is recently updated.
@@ -177,7 +248,7 @@ class Schema(Mapping[str, VT], Generic[VT]):
     #: List of names to be excluded from :obj:`dict` conversion.
     __excluded__: 'list[str]' = []
 
-    def __new__(cls, *args: 'VT', **kwargs: 'VT') -> 'Self':  # pylint: disable=unused-argument
+    def __new__(cls, *args: '_VT', **kwargs: '_VT') -> 'Self':  # pylint: disable=unused-argument
         """Create a new instance.
 
         The class will try to automatically generate ``__init__`` method with
@@ -212,8 +283,8 @@ class Schema(Mapping[str, VT], Generic[VT]):
                 self.__dict__[name] = field.default
         self.pack(packet)
 
-    def __update__(self, dict_: 'Optional[Mapping[str, VT] | Iterable[tuple[str, VT]]]' = None,
-                   **kwargs: 'VT') -> 'None':
+    def __update__(self, dict_: 'Optional[Mapping[str, _VT] | Iterable[tuple[str, _VT]]]' = None,
+                   **kwargs: '_VT') -> 'None':
         # NOTE: Keys with the same names as the class's builtin methods will be
         # renamed with the class name prefixed as mangled class variables
         # implicitly and internally. Such mapping information will be stored
@@ -301,13 +372,13 @@ class Schema(Mapping[str, VT], Generic[VT]):
                 continue
             yield self.__map_reverse__.get(key, key)
 
-    def __getitem__(self, name: 'str') -> 'VT':
+    def __getitem__(self, name: 'str') -> '_VT':
         if name in self.__fields__:
             key = self.__map__.get(name, name)
             return self.__dict__[key]
         return super().__getitem__(name)
 
-    def __setattr__(self, name: 'str', value: 'VT') -> 'None':
+    def __setattr__(self, name: 'str', value: '_VT') -> 'None':
         if name in self.__fields__:
             key = self.__map__.get(name, name)
             self.__dict__[key] = value
@@ -324,8 +395,8 @@ class Schema(Mapping[str, VT], Generic[VT]):
         return super().__delattr__(name)
 
     @classmethod
-    def from_dict(cls, dict_: 'Optional[Mapping[str, VT] | Iterable[tuple[str, VT]]]' = None,
-                  **kwargs: 'VT') -> 'Self':
+    def from_dict(cls, dict_: 'Optional[Mapping[str, _VT] | Iterable[tuple[str, _VT]]]' = None,
+                  **kwargs: '_VT') -> 'Self':
         r"""Create a new instance.
 
         * If ``dict_`` is present and has a ``.keys()`` method, then does:
@@ -345,7 +416,7 @@ class Schema(Mapping[str, VT], Generic[VT]):
         self.__post_init__()
         return self
 
-    def to_dict(self) -> 'dict[str, VT]':
+    def to_dict(self) -> 'dict[str, _VT]':
         """Convert :class:`Schema` into :obj:`dict`.
 
         Important:
@@ -603,3 +674,136 @@ class Schema(Mapping[str, VT], Generic[VT]):
 
         """
         return self
+
+
+class EnumMeta(SchemaMeta, Generic[_ET]):
+    """Meta class to add dynamic support for :class:`EnumSchema`.
+
+    This meta class is used to generate necessary attributes for the
+    :class:`SchemaMeta` class. It can be useful to reduce runtime generation
+    cost as well as caching already generated attributes.
+
+    * :attr:`~EnumSchema.registry` is added to subclasses as an *immutable*
+      proxy (similar to :class:`property`, but on class variables) to the
+      :attr:`EnumSchema.__enum__` mapping.
+
+    """
+
+    if TYPE_CHECKING:
+        #: Mapping of enumeration numbers to schemas (**internal use only**).
+        __enum__: 'DefaultDict[_ET, Type[EnumSchema]]'
+
+    @property
+    def registry(cls) -> 'DefaultDict[_ET, Type[EnumSchema]]':
+        """Mapping of enumeration numbers to schemas."""
+        return cls.__enum__
+
+
+class EnumSchema(Schema, Generic[_ET], metaclass=EnumMeta):
+    """:class:`Schema` with enumeration mapping support.
+
+    Examples:
+
+        To create an enumeration mapping supported schema, simply
+
+        .. code-block:: python
+
+           class MySchema(EnumSchema[MyEnum]):
+
+               # optional, set the default schema for enumeration mapping
+               # if the enumeration number is not found in the mapping
+               __default__ = lambda: UnknownSchema  # by default, None
+
+        then, you can use inheritance to create a list of schemas
+        for this given enumeration mapping:
+
+        .. code-block:: python
+
+           class OneSchema(MySchema, code=MyEnum.ONE):
+               ...
+
+           class MultipleSchema(MySchema, code=[MyEnum.TWO, MyEnum.THREE]):
+               ...
+
+        or optionally, using the :meth:`register` method to register a
+        schema to the enumeration mapping:
+
+        .. code-block:: python
+
+           MySchema.register(MyEnum.ZERO, ZeroSchema)
+
+        And now you can access the enumeration mapping via the :attr:`registry`
+        property (more specifically, class attribute):
+
+        .. code-block:: python
+
+           >>> MySchema.registry[MyEnum.ONE]  # OneSchema
+
+    """
+
+    __additional__ = ['__enum__', '__default__']
+    __excluded__ = ['__enum__', '__default__']
+
+    #: Callback to return the default schema for enumeration mapping,
+    #: by default is a ``lambda: None`` statement.
+    __default__: 'Callable[[], Type[Self]]' = lambda: None  # type: ignore[assignment,return-value]
+
+    if TYPE_CHECKING:
+        #: Mapping of enumeration numbers to schemas.
+        __enum__: 'DefaultDict[_ET, Type[Self]]'
+
+    @property
+    def registry(self) -> 'DefaultDict[_ET, Type[Self]]':
+        """Mapping of enumeration numbers to schemas.
+
+        Note:
+            This property is also available as a class
+            attribute.
+
+        """
+        return self.__enum__
+
+    def __init_subclass__(cls, /, code: 'Optional[_ET | Iterable[_ET]]' = None, *args: 'Any', **kwargs: 'Any') -> 'None':
+        """Register enumeration to :attr:`registry` mapping.
+
+        Args:
+            code: Enumeration code. It can be either a single enumeration
+                or a list of enumerations.
+            *args: Arbitrary positional arguments.
+            **kwargs: Arbitrary keyword arguments.
+
+        If ``code`` is provided, the subclass will be registered to the
+        :attr:`registry` mapping with the given ``code``. If ``code`` is
+        not given, the subclass will not be registered.
+
+        Notes:
+            If :attr:`__enum__` is not yet defined at function call,
+            it will automatically be defined as a :class:`collections.defaultdict`
+            object, with the default value set to :attr:`__default__`.
+
+            If intended to customise the :attr:`__enum__` mapping,
+            it is possible to override the :meth:`__init_subclass__` method and
+            define :attr:`__enum__` manually.
+
+        """
+        if not hasattr(cls, '__enum__'):
+            cls.__enum__ = collections.defaultdict(cls.__default__)
+
+        if code is not None:
+            if isinstance(code, collections.abc.Iterable):
+                for _code in code:
+                    cls.__enum__[_code] = (cls)  # type: ignore[index]
+            else:
+                cls.__enum__[code] = (cls)  # type: ignore[index]
+        super().__init_subclass__()
+
+    @classmethod
+    def register(cls, code: '_ET', schema: 'Type[Self]') -> 'None':
+        """Register enumetaion to :attr:`__enum__` mapping.
+
+        Args:
+            code: Enumetaion code.
+            schema: Enumetaion schema.
+
+        """
+        cls.__enum__[code] = schema  # type: ignore[index]
