@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
+# mypy: disable-error-code=dict-item
 """UDP - User Datagram Protocol
 ==================================
 
+.. module:: pcapkit.protocols.transport.udp
+
 :mod:`pcapkit.protocols.transport.udp` contains
 :class:`~pcapkit.protocols.transport.udp.UDP` only,
 which implements extractor for User Datagram Protocol
@@ -22,19 +25,26 @@ Octets      Bits        Name                    Description
 import collections
 from typing import TYPE_CHECKING
 
-from pcapkit.const.reg.transtype import TransType as RegType_TransType
-from pcapkit.protocols.data.transport.udp import UDP as DataType_UDP
+from pcapkit.const.reg.transtype import TransType as Enum_TransType
+from pcapkit.corekit.module import ModuleDescriptor
+from pcapkit.protocols.data.transport.udp import UDP as Data_UDP
+from pcapkit.protocols.schema.transport.udp import UDP as Schema_UDP
 from pcapkit.protocols.transport.transport import Transport
 
 if TYPE_CHECKING:
-    from typing import Any, NoReturn, Optional
+    from typing import Any, Optional
 
     from typing_extensions import Literal
 
+    from pcapkit.const.reg.apptype import AppType as Enum_AppType
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
+    from pcapkit.protocols.schema.schema import Schema
+
 __all__ = ['UDP']
 
 
-class UDP(Transport[DataType_UDP]):
+class UDP(Transport[Data_UDP, Schema_UDP],
+          schema=Schema_UDP, data=Data_UDP):
     """This class implements User Datagram Protocol.
 
     This class currently supports parsing of the following protocols, which are
@@ -55,13 +65,14 @@ class UDP(Transport[DataType_UDP]):
     # Defaults.
     ##########################################################################
 
-    #: DefaultDict[int, tuple[str, str]]: Protocol index mapping for decoding next layer,
-    #: c.f. :meth:`self._decode_next_layer <pcapkit.protocols.transport.transport.Transport._decode_next_layer>`
+    #: DefaultDict[int, ModuleDescriptor[Protocol] | Type[Protocol]]: Protocol
+    #: index mapping for decoding next layer, c.f.
+    #: :meth:`self._decode_next_layer <pcapkit.protocols.transport.transport.Transport._decode_next_layer>`
     #: & :meth:`self._import_next_layer <pcapkit.protocols.protocol.Protocol._import_next_layer>`.
     __proto__ = collections.defaultdict(
-        lambda: ('pcapkit.protocols.misc.raw', 'Raw'),
+        lambda: ModuleDescriptor('pcapkit.protocols.misc.raw', 'Raw'),  # type: ignore[arg-type,return-value]
         {
-            80: ('pcapkit.protocols.application.http', 'HTTP'),  # HTTP
+            80: ModuleDescriptor('pcapkit.protocols.application.http', 'HTTP'),  # HTTP
         },
     )
 
@@ -80,12 +91,12 @@ class UDP(Transport[DataType_UDP]):
         return 8
 
     @property
-    def src(self) -> 'int':
+    def src(self) -> 'Enum_AppType':
         """Source port."""
         return self._info.srcport
 
     @property
-    def dst(self) -> 'int':
+    def dst(self) -> 'Enum_AppType':
         """Destination port."""
         return self._info.dstport
 
@@ -93,7 +104,7 @@ class UDP(Transport[DataType_UDP]):
     # Methods.
     ##########################################################################
 
-    def read(self, length: 'Optional[int]' = None, **kwargs: 'Any') -> 'DataType_UDP':  # pylint: disable=unused-argument
+    def read(self, length: 'Optional[int]' = None, **kwargs: 'Any') -> 'Data_UDP':  # pylint: disable=unused-argument
         """Read User Datagram Protocol (UDP).
 
         Structure of UDP header [:rfc:`768`]:
@@ -122,32 +133,43 @@ class UDP(Transport[DataType_UDP]):
         """
         if length is None:
             length = len(self)
+        schema = self.__header__
 
-        _srcp = self._read_unpack(2)
-        _dstp = self._read_unpack(2)
-        _tlen = self._read_unpack(2)
-        _csum = self._read_fileng(2)
-
-        udp = DataType_UDP(
-            srcport=_srcp,
-            dstport=_dstp,
-            len=_tlen,
-            checksum=_csum,
+        udp = Data_UDP(
+            srcport=schema.srcport,
+            dstport=schema.dstport,
+            len=schema.len,
+            checksum=schema.checksum,
         )
 
-        return self._decode_next_layer(udp, (udp.srcport, udp.dstport), udp.len - 8)
+        return self._decode_next_layer(udp, (udp.srcport.port, udp.dstport.port), udp.len - 8)
 
-    def make(self, **kwargs: 'Any') -> 'NoReturn':
+    def make(self,
+             srcport: 'Enum_AppType | int' = 0,
+             dstport: 'Enum_AppType | int' = 0,
+             checksum: 'bytes' = b'\x00\x00',
+             payload: 'bytes | Schema | Protocol' = b'',
+             **kwargs: 'Any') -> 'Schema_UDP':
         """Make (construct) packet data.
 
         Args:
+            srcport: Source port.
+            dstport: Destination port.
+            checksum: Checksum.
+            payload: Payload data.
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
             Constructed packet data.
 
         """
-        raise NotImplementedError
+        return Schema_UDP(
+            srcport=srcport,
+            dstport=dstport,
+            len=8 + len(payload),
+            checksum=checksum,
+            payload=payload,
+        )
 
     ##########################################################################
     # Data models.
@@ -158,7 +180,7 @@ class UDP(Transport[DataType_UDP]):
         return 8
 
     @classmethod
-    def __index__(cls) -> 'RegType_TransType':  # pylint: disable=invalid-index-returned
+    def __index__(cls) -> 'Enum_TransType':  # pylint: disable=invalid-index-returned
         """Numeral registry index of the protocol.
 
         Returns:
@@ -167,4 +189,26 @@ class UDP(Transport[DataType_UDP]):
         .. _IANA: https://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml
 
         """
-        return RegType_TransType.UDP  # type: ignore[return-value]
+        return Enum_TransType.UDP  # type: ignore[return-value]
+
+    ##########################################################################
+    # Utilities.
+    ##########################################################################
+
+    @classmethod
+    def _make_data(cls, data: 'Data_UDP') -> 'dict[str, Any]':  # type: ignore[override]
+        """Create key-value pairs from ``data`` for protocol construction.
+
+        Args:
+            data: protocol data
+
+        Returns:
+            Key-value pairs for protocol construction.
+
+        """
+        return {
+            'srcport': data.srcport,
+            'dstport': data.dstport,
+            'checksum': data.checksum,
+            'payload': cls._make_payload(data),
+        }
