@@ -4,22 +4,24 @@ import sys
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from typing import Any, Callable, Generator, Optional, Type, Union
+    from typing import Any, Callable, Iterator, Optional, Type, Union
 
 __all__ = [
     # functions
-    'final', 'localcontext',
+    'final', 'localcontext', 'show_flag_values',
 
     # exceptions
     'ModuleNotFoundError',
 
     # classes
     'Collection', 'cached_property',
-    'Mapping', 'Tuple', 'List', 'Dict',
     'StrEnum',
 
     # modules
     'pathlib',
+
+    # typing
+    'Mapping', 'Tuple', 'List', 'Dict', 'TypeAlias',
 ]
 
 if sys.version_info < (3, 6):
@@ -125,9 +127,9 @@ if sys.version_info < (3, 9):
 else:
     from collections.abc import Mapping
 
-    Tuple = tuple
-    List = list
-    Dict = dict
+    Tuple: 'TypeAlias' = tuple
+    List: 'TypeAlias' = list
+    Dict: 'TypeAlias' = dict
 
 if sys.version_info < (3, 11):
     from aenum import StrEnum
@@ -164,3 +166,31 @@ if sys.version_info < (3, 11):
             yield lc
 else:
     from decimal import localcontext
+
+if sys.version_info < (3, 11):
+    from enum import Enum
+
+    if TYPE_CHECKING:
+        from enum import IntFlag
+
+    def _iter_bits_lsb(num: 'int') -> 'Iterator[int]':
+        # num must be a positive integer
+        original = num
+        if isinstance(num, Enum):
+            num = num.value
+        if num < 0:
+            raise ValueError('%r is not a positive integer' % original)
+        while num:
+            b = num & (~num + 1)
+            yield b
+            num ^= b
+
+    def show_flag_values(value: 'IntFlag') -> 'list[int]':
+        return list(_iter_bits_lsb(value))
+else:
+    from enum import show_flag_values  # type: ignore[attr-defined]
+
+if sys.version_info < (3, 10):
+    from typing_extensions import TypeAlias
+else:
+    from typing import TypeAlias
