@@ -14,16 +14,18 @@ decorators, including :func:`~pcapkit.utilities.decorators.seekset`,
 import functools
 import io
 import os
+import traceback
 from typing import TYPE_CHECKING, cast
 
-from pcapkit.utilities.exceptions import StructError
+from pcapkit.utilities.exceptions import StructError, stacklevel
+from pcapkit.utilities.logging import DEVMODE, VERBOSE, logger
 
 if TYPE_CHECKING:
     from typing import IO, Any, Callable, Optional, Type, TypeVar
 
     from typing_extensions import Concatenate, ParamSpec
 
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
     from pcapkit.protocols.schema.schema import Schema
 
     P = ParamSpec('P')
@@ -48,7 +50,8 @@ def seekset(func: 'Callable[Concatenate[Protocol, P], R_seekset]') -> 'Callable[
     Note:
         The decorated function should have following signature::
 
-            func(self, *args, **kw)
+            func(self: 'pcapkit.protocols.protocol.ProtocolBase',
+                 *args: 'typing.Any', **kwargs: 'typing.Any') -> 'typing.Any'
 
     See Also:
         :meth:`pcapkit.protocols.protocol.Protocol._read_packet`
@@ -89,7 +92,9 @@ def beholder(func: 'Callable[Concatenate[Protocol, int, Optional[int], P], R_beh
     Note:
         The decorated function should have following signature::
 
-            func(self, proto, length, *args, **kwargs)
+            func(self: 'pcapkit.protocols.protocol.ProtocolBase',
+                 proto: 'int', length: 'typing.Optional[int]',
+                 *args: 'typing.Any', **kwargs: 'typing.Any') -> 'pcapkit.protocols.protocol.ProtocolBase'
 
     See Also:
         :meth:`pcapkit.protocols.protocol.Protocol._decode_next_layer`
@@ -118,9 +123,9 @@ def beholder(func: 'Callable[Concatenate[Protocol, int, Optional[int], P], R_beh
             # error = traceback.format_exc(limit=1).strip().rsplit(os.linesep, maxsplit=1)[-1]
 
             # log error
-            # logger.error(str(exc), exc_info=exc, stack_info=DEVMODE, stacklevel=stacklevel())
-            # if DEVMODE:
-            #    traceback.print_exc()
+            logger.error(str(exc), exc_info=exc, stack_info=DEVMODE, stacklevel=stacklevel())
+            if VERBOSE:
+               traceback.print_exc()
 
             file_ = self.__header__.get_payload()
             next_ = protocol(file_, length, error=str(exc))
@@ -144,7 +149,11 @@ def prepare(func: 'Callable[Concatenate[Type[R_prepare], bytes | IO[bytes], Opti
     Note:
         The decorated function should have following signature::
 
-            func(cls, data, length, packet, *args, **kwargs)
+            func(cls: 'typing.Type[pcapkit.protocols.schema.schema.Schema]',
+                 data: 'bytes | typing.IO[bytes]',
+                 length: 'Optional[int],
+                 packet: 'Optional[dict[str, Any]',
+                 *args: 'typing.Any', **kwargs: 'Any') -> 'pcapkit.protocols.schema.schema.Schema'
 
     See Also:
         :meth:`pcapkit.protocols.schema.schema.Schema.unpack`
